@@ -28,12 +28,6 @@ class Settings;
  */
 void set_default_settings(Settings *settings);
 
-/**
- * initialize default values which require knowledge about gui
- * @param settings pointer to settings
- */
-void late_init_default_settings(Settings* settings);
-
 /**
  * override a default settings by settings from another settings element
  * @param settings target settings pointer
